# Core Angular Template (ANGULAR 16)

This helper is a basic schematic to initialize an Angular **16** Architecture properly.

It is now module-less with v16.

### Before ⚠️

Init an Angular Project with SCSS configuration and no test.

```bash
ng new my-app --strict --standalone --routing --skip-tests --style scss
```

### Running

Just do after initialization

```bash
ng add core-angular-template
```

That's it! 🚀


#### *From*

```
📦my-app
┣ 📂src
┃ ┣ 📂app
┃ ┃ ┣ 📜app-routing.module.ts
┃ ┃ ┣ 📜app.component.html
┃ ┃ ┣ 📜app.component.scss
┃ ┃ ┣ 📜app.component.ts
┃ ┃ ┗ 📜app.module.ts
┃ ┣ 📂assets
┃ ┃ ┗ 📜.gitkeep
┃ ┣ 📂environments
┃ ┃ ┣ 📜environment.prod.ts
┃ ┃ ┗ 📜environment.ts
┃ ┣ 📜favicon.ico
┃ ┣ 📜index.html
┃ ┣ 📜main.ts
┃ ┣ 📜polyfills.ts
┃ ┣ 📜styles.scss
┃ ┗ 📜test.ts
┣ 📜.browserslistrc
┣ 📜.editorconfig
┣ 📜.gitignore
┣ 📜angular.json
┣ 📜karma.conf.js
┣ 📜package-lock.json
┣ 📜package.json
┣ 📜README.md
┣ 📜tsconfig.app.json
┣ 📜tsconfig.json
┗ 📜tsconfig.spec.json
```

#### *To*

``` 
📦my-app
 ┣ 📂src
 ┃ ┣ 📂app
 ┃ ┃ ┣ 📂models
 ┃ ┃ ┃ ┣ 📂enum
 ┃ ┃ ┃ ┃ ┗ 📜template.enum.ts
 ┃ ┃ ┃ ┗ 📜template.model.ts
 ┃ ┃ ┣ 📂pages
 ┃ ┃ ┃ ┗ 📂home
 ┃ ┃ ┃ ┃ ┣ 📜home.component.html
 ┃ ┃ ┃ ┃ ┣ 📜home.component.scss
 ┃ ┃ ┃ ┃ ┗ 📜home.component.ts
 ┃ ┃ ┣ 📂services
 ┃ ┃ ┃ ┣ 📂webservices
 ┃ ┃ ┃ ┃ ┗ 📜template.service.ts
 ┃ ┃ ┃ ┣ 📜loading.service.ts
 ┃ ┃ ┃ ┗ 📜local-storage.service.ts
 ┃ ┃ ┣ 📂shared
 ┃ ┃ ┃ ┣ 📂directives
 ┃ ┃ ┃ ┃ ┣ 📜resizable.directive.ts
 ┃ ┃ ┃ ┃ ┗ 📜template.directive.ts
 ┃ ┃ ┃ ┣ 📂helpers
 ┃ ┃ ┃ ┃ ┗ 📜template.helper.ts
 ┃ ┃ ┃ ┣ 📂injectables
 ┃ ┃ ┃ ┃ ┗ 📜destroyed.injectable.ts
 ┃ ┃ ┃ ┣ 📂interceptor
 ┃ ┃ ┃ ┃ ┗ 📜loading.interceptor.ts
 ┃ ┃ ┃ ┣ 📂pipes
 ┃ ┃ ┃ ┃ ┗ 📜template.pipe.ts
 ┃ ┃ ┃ ┣ 📂ui
 ┃ ┃ ┃ ┃ ┣ 📂loading
 ┃ ┃ ┃ ┃ ┃ ┣ 📜loading.component.html
 ┃ ┃ ┃ ┃ ┃ ┣ 📜loading.component.scss
 ┃ ┃ ┃ ┃ ┃ ┗ 📜loading.component.ts
 ┃ ┃ ┃ ┃ ┣ 📂resizable-exemple
 ┃ ┃ ┃ ┃ ┃ ┣ 📜resizable-exemple.component.html
 ┃ ┃ ┃ ┃ ┃ ┣ 📜resizable-exemple.component.scss
 ┃ ┃ ┃ ┃ ┃ ┗ 📜resizable-exemple.component.ts
 ┃ ┃ ┃ ┃ ┗ 📂template
 ┃ ┃ ┃ ┃ ┃ ┣ 📜template.component.html
 ┃ ┃ ┃ ┃ ┃ ┣ 📜template.component.scss
 ┃ ┃ ┃ ┃ ┃ ┗ 📜template.component.ts
 ┃ ┃ ┃ ┣ 📂utils
 ┃ ┃ ┃ ┃ ┗ 📜utils.static.ts
 ┃ ┃ ┃ ┗ 📜shared.module.ts
 ┃ ┃ ┣ 📜app-routing.module.ts
 ┃ ┃ ┣ 📜app.component.html
 ┃ ┃ ┣ 📜app.component.scss
 ┃ ┃ ┣ 📜app.component.ts
 ┃ ┃ ┗ 📜app.module.ts
 ┃ ┣ 📂assets
 ┃ ┃ ┗ 📜.gitkeep
 ┃ ┣ 📂environments
 ┃ ┃ ┣ 📜environment.prod.ts
 ┃ ┃ ┗ 📜environment.ts
 ┃ ┣ 📜favicon.ico
 ┃ ┣ 📜index.html
 ┃ ┣ 📜main.ts
 ┃ ┣ 📜styles.scss
 ┃ ┗ 📜test.ts
 ┣ 📜.browserslistrc
 ┣ 📜.editorconfig
 ┣ 📜.gitignore
 ┣ 📜angular.json
 ┣ 📜karma.conf.js
 ┣ 📜package-lock.json
 ┣ 📜package.json
 ┣ 📜README.md
 ┣ 📜tsconfig.app.json
 ┣ 📜tsconfig.json
 ┗ 📜tsconfig.spec.json
``` 
